pub async fn admin_issue_api_key(
configuration: &Configuration,
issue_api_key_request: IssueApiKeyRequest,
) -> Result<IssueApiKeyResponse, Error<AdminIssueApiKeyError>>Expand description
Creates a new API key for a given actor. The secret is returned only once in the response and cannot be retrieved later. Keys can be scoped with specific permissions and have optional expiration. http POST /v2alpha1/admin/issuedApiKeys { \"name\": \"production-service\", \"actor_id\": \"user_123\", \"scopes\": [\"read\", \"write\"], \"ttl\": \"8760h\" }