pub async fn get_flow_error(
configuration: &Configuration,
id: &str,
) -> Result<FlowError, Error<GetFlowErrorError>>Expand description
This endpoint returns the error associated with a user-facing self service errors. This endpoint supports stub values to help you implement the error UI: ?id=stub:500 - returns a stub 500 (Internal Server Error) error. More information can be found at Ory Kratos User User Facing Error Documentation.