batch_patch_identities

Function batch_patch_identities 

pub async fn batch_patch_identities(
    configuration: &Configuration,
    patch_identities_body: Option<PatchIdentitiesBody>,
) -> Result<BatchPatchIdentitiesResponse, Error<BatchPatchIdentitiesError>>
Creates multiple identities. You can also use this endpoint to import credentials, including passwords, social sign-in settings, and multi-factor authentication methods. If the patch includes hashed passwords you can import up to 1,000 identities per request. If the patch includes at least one plaintext password you can import up to 200 identities per request. Avoid importing large batches with plaintext passwords. They can cause timeouts as the passwords need to be hashed before they are stored. If at least one identity is imported successfully, the response status is 200 OK. If all imports fail, the response is one of the following 4xx errors: 400 Bad Request: The request payload is invalid or improperly formatted. 409 Conflict: Duplicate identities or conflicting data were detected. If you get a 504 Gateway Timeout: Reduce the batch size Avoid duplicate identities Pre-hash passwords with BCrypt If the issue persists, contact support.