Module metadata_api

Module metadata_api 

Enums

GetVersionError
struct for typed errors of method get_version

Functions

get_version
This endpoint returns the version of Ory Kratos. If the service supports TLS Edge Termination, this endpoint does not require the X-Forwarded-Proto header to be set. Be aware that if you are running multiple nodes of this service, the version will never refer to the cluster state, only to a single instance.