get_version

Function get_version 

pub async fn get_version(
    configuration: &Configuration,
) -> Result<GetVersion200Response, Error<GetVersionError>>
This endpoint returns the version of Ory Kratos. If the service supports TLS Edge Termination, this endpoint does not require the X-Forwarded-Proto header to be set. Be aware that if you are running multiple nodes of this service, the version will never refer to the cluster state, only to a single instance.