pub async fn patch_o_auth2_client(
configuration: &Configuration,
id: &str,
json_patch: Vec<JsonPatch>,
) -> Result<OAuth2Client, Error<PatchOAuth2ClientError>>Expand description
Patch an existing OAuth 2.0 Client using JSON Patch. If you pass client_secret the secret will be updated and returned via the API. This is the only time you will be able to retrieve the client secret, so write it down and keep it safe. OAuth 2.0 clients are used to perform OAuth 2.0 and OpenID Connect flows. Usually, OAuth 2.0 clients are generated for applications which want to consume your OAuth 2.0 or OpenID Connect capabilities.