Module project_api

Module project_api 

Enums

CreateOrganizationError
struct for typed errors of method create_organization
CreateOrganizationOnboardingPortalLinkError
struct for typed errors of method create_organization_onboarding_portal_link
CreateProjectApiKeyError
struct for typed errors of method create_project_api_key
CreateProjectError
struct for typed errors of method create_project
DeleteOrganizationError
struct for typed errors of method delete_organization
DeleteOrganizationOnboardingPortalLinkError
struct for typed errors of method delete_organization_onboarding_portal_link
DeleteProjectApiKeyError
struct for typed errors of method delete_project_api_key
GetOrganizationError
struct for typed errors of method get_organization
GetOrganizationOnboardingPortalLinksError
struct for typed errors of method get_organization_onboarding_portal_links
GetProjectError
struct for typed errors of method get_project
GetProjectMembersError
struct for typed errors of method get_project_members
ListOrganizationsError
struct for typed errors of method list_organizations
ListProjectApiKeysError
struct for typed errors of method list_project_api_keys
ListProjectsError
struct for typed errors of method list_projects
PatchProjectError
struct for typed errors of method patch_project
PatchProjectWithRevisionError
struct for typed errors of method patch_project_with_revision
PurgeProjectError
struct for typed errors of method purge_project
RemoveProjectMemberError
struct for typed errors of method remove_project_member
SetProjectError
struct for typed errors of method set_project
UpdateOrganizationError
struct for typed errors of method update_organization
UpdateOrganizationOnboardingPortalLinkError
struct for typed errors of method update_organization_onboarding_portal_link

Functions

create_organization
Deprecated: use setProject or patchProjectWithRevision instead Creates an Enterprise SSO Organization in a project.
create_organization_onboarding_portal_link
Create a onboarding portal link for an organization.
create_project
Creates a new project.
create_project_api_key
Create an API key for a project.
delete_organization
Deprecated: use setProject or patchProjectWithRevision instead Irrecoverably deletes an Enterprise SSO Organization in a project by its ID.
delete_organization_onboarding_portal_link
Deletes a onboarding portal link for an organization.
delete_project_api_key
Deletes an API key and immediately removes it.
get_organization
Deprecated: use getProject instead Retrieves an Enterprise SSO Organization for a project by its ID
get_organization_onboarding_portal_links
Retrieves the organization onboarding portal links.
get_project
Get a project you have access to by its ID.
get_project_members
This endpoint requires the user to be a member of the project with the role OWNER or DEVELOPER.
list_organizations
Deprecated: use getProject instead Lists all Enterprise SSO organizations in a project.
list_project_api_keys
A list of all the project’s API keys.
list_projects
Lists all projects you have access to.
patch_project
Deprecated: Use the patchProjectWithRevision endpoint instead to specify the exact revision the patch was generated for. This endpoints allows you to patch individual Ory Network project configuration keys for Ory’s services (identity, permission, …). The configuration format is fully compatible with the open source projects for the respective services (e.g. Ory Kratos for Identity, Ory Keto for Permissions). This endpoint expects the version key to be set in the payload. If it is unset, it will try to import the config as if it is from the most recent version. If you have an older version of a configuration, you should set the version key in the payload! While this endpoint is able to process all configuration items related to features (e.g. password reset), it does not support operational configuration items (e.g. port, tracing, logging) otherwise available in the open source. For configuration items that can not be translated to the Ory Network, this endpoint will return a list of warnings to help you understand which parts of your config could not be processed.
patch_project_with_revision
This endpoints allows you to patch individual Ory Network Project configuration keys for Ory’s services (identity, permission, …). The configuration format is fully compatible with the open source projects for the respective services (e.g. Ory Kratos for Identity, Ory Keto for Permissions). This endpoint expects the version key to be set in the payload. If it is unset, it will try to import the config as if it is from the most recent version. If you have an older version of a configuration, you should set the version key in the payload! While this endpoint is able to process all configuration items related to features (e.g. password reset), it does not support operational configuration items (e.g. port, tracing, logging) otherwise available in the open source. For configuration items that can not be translated to the Ory Network, this endpoint will return a list of warnings to help you understand which parts of your config could not be processed.
purge_project
!! Use with extreme caution !! Using this API endpoint you can purge (completely delete) a project and its data. This action can not be undone and will delete ALL your data. Calling this endpoint will additionally delete custom domains and other related data. If the project is linked to a subscription, the subscription needs to be unlinked first.
remove_project_member
This also sets their invite status to REMOVED. This endpoint requires the user to be a member of the project with the role OWNER.
set_project
This endpoints allows you to update the Ory Network project configuration for individual services (identity, permission, …). The configuration is fully compatible with the open source projects for the respective services (e.g. Ory Kratos for Identity, Ory Keto for Permissions). This endpoint expects the version key to be set in the payload. If it is unset, it will try to import the config as if it is from the most recent version. If you have an older version of a configuration, you should set the version key in the payload! While this endpoint is able to process all configuration items related to features (e.g. password reset), it does not support operational configuration items (e.g. port, tracing, logging) otherwise available in the open source. For configuration items that can not be translated to the Ory Network, this endpoint will return a list of warnings to help you understand which parts of your config could not be processed. Be aware that updating any service’s configuration will completely override your current configuration for that service!
update_organization
Deprecated: use setProject or patchProjectWithRevision instead Updates an Enterprise SSO Organization in a project by its ID.
update_organization_onboarding_portal_link
Update a onboarding portal link for an organization.