Module relationship_api

Module relationship_api 

Enums

CheckOplSyntaxError
struct for typed errors of method check_opl_syntax
CreateRelationshipError
struct for typed errors of method create_relationship
DeleteRelationshipsError
struct for typed errors of method delete_relationships
GetRelationshipsError
struct for typed errors of method get_relationships
ListRelationshipNamespacesError
struct for typed errors of method list_relationship_namespaces
PatchRelationshipsError
struct for typed errors of method patch_relationships

Functions

check_opl_syntax
The OPL file is expected in the body of the request.
create_relationship
Use this endpoint to create a relationship.
delete_relationships
Use this endpoint to delete relationships
get_relationships
Get all relationships that match the query. Only the namespace field is required.
list_relationship_namespaces
Get all namespaces
patch_relationships
Use this endpoint to patch one or more relationships.