Module basic_organization

Module basic_organization 

Structs

BasicOrganization

Enums

DefaultRegionEnum
DefaultRegion sets the default region for identities provisioned into this organization, when the identity does not specify a region explictly. eu-central EUCentral asia-northeast AsiaNorthEast us-east USEast us-west USWest eu EU asia Asia us US global Global