pub struct BatchImportResult {
pub error_code: Option<BatchImportErrorCode>,
pub error_message: Option<String>,
pub imported_api_key: Option<Box<ImportedApiKey>>,
pub index: Option<i32>,
}Expand description
BatchImportResult : BatchImportResult contains the result for one key in a batch import request.
Fields
error_code: Option<BatchImportErrorCode>error_message: Option<String>imported_api_key: Option<Box<ImportedApiKey>>index: Option<i32>Implementations
Sourceimpl BatchImportResult
impl BatchImportResult
Sourcepub fn new() -> BatchImportResult
pub fn new() -> BatchImportResult
BatchImportResult contains the result for one key in a batch import request.