pub struct ContinueWithRecoveryUi {
pub action: ActionEnum,
pub flow: Box<ContinueWithRecoveryUiFlow>,
}Expand description
ContinueWithRecoveryUi : Indicates, that the UI flow could be continued by showing a recovery ui
Fields
action: ActionEnumAction will always be show_recovery_ui show_recovery_ui ContinueWithActionShowRecoveryUIString
flow: Box<ContinueWithRecoveryUiFlow>Implementations
Sourceimpl ContinueWithRecoveryUi
impl ContinueWithRecoveryUi
Sourcepub fn new(
action: ActionEnum,
flow: ContinueWithRecoveryUiFlow,
) -> ContinueWithRecoveryUi
pub fn new( action: ActionEnum, flow: ContinueWithRecoveryUiFlow, ) -> ContinueWithRecoveryUi
Indicates, that the UI flow could be continued by showing a recovery ui