pub struct ContinueWithSettingsUi {
pub action: ActionEnum,
pub flow: Box<ContinueWithSettingsUiFlow>,
}Expand description
ContinueWithSettingsUi : Indicates, that the UI flow could be continued by showing a settings ui
Fields
action: ActionEnumAction will always be show_settings_ui show_settings_ui ContinueWithActionShowSettingsUIString
flow: Box<ContinueWithSettingsUiFlow>Implementations
Sourceimpl ContinueWithSettingsUi
impl ContinueWithSettingsUi
Sourcepub fn new(
action: ActionEnum,
flow: ContinueWithSettingsUiFlow,
) -> ContinueWithSettingsUi
pub fn new( action: ActionEnum, flow: ContinueWithSettingsUiFlow, ) -> ContinueWithSettingsUi
Indicates, that the UI flow could be continued by showing a settings ui