pub struct ContinueWithSettingsUiFlow {
pub id: String,
pub url: Option<String>,
}Fields
id: StringThe ID of the settings flow
url: Option<String>The URL of the settings flow If this value is set, redirect the user’s browser to this URL. This value is typically unset for native clients / API flows.
Implementations
Sourceimpl ContinueWithSettingsUiFlow
impl ContinueWithSettingsUiFlow
pub fn new(id: String) -> ContinueWithSettingsUiFlow