pub struct ContinueWithVerificationUi {
pub action: ActionEnum,
pub flow: Box<ContinueWithVerificationUiFlow>,
}Expand description
ContinueWithVerificationUi : Indicates, that the UI flow could be continued by showing a verification ui
Fields
action: ActionEnumAction will always be show_verification_ui show_verification_ui ContinueWithActionShowVerificationUIString
flow: Box<ContinueWithVerificationUiFlow>Implementations
Sourceimpl ContinueWithVerificationUi
impl ContinueWithVerificationUi
Sourcepub fn new(
action: ActionEnum,
flow: ContinueWithVerificationUiFlow,
) -> ContinueWithVerificationUi
pub fn new( action: ActionEnum, flow: ContinueWithVerificationUiFlow, ) -> ContinueWithVerificationUi
Indicates, that the UI flow could be continued by showing a verification ui