Structs
- Create
Project Normalized Payload - CreateProjectNormalizedPayload : Create project (normalized) request payload
Enums
- Environment
Enum - prod Production stage Staging dev Development
- Home
Region Enum - eu-central EUCentral asia-northeast AsiaNorthEast us-east USEast us-west USWest us US global Global
- Hydra
Strategies Access Token Enum - Defines access token type This governs the "strategies.access_token" setting. opaque Oauth2AccessTokenStrategyOpaque jwt Oauth2AccessTokenStrategyJwt
- Hydra
Strategies JwtScope Claim Enum - Define the claim to use as the scope in the access token. This governs the "strategies.jwt.scope_claim" setting: list: The scope claim is an array of strings named
scope:{ \"scope\": [\"read\", \"write\"] }string: The scope claim is a space delimited list of strings namedscp:{ \"scp\": \"read write\" }both: The scope claim is both a space delimited list and an array of strings namedscopeandscp:{ \"scope\": [\"read\", \"write\"], \"scp\": \"read write\" }list OAuth2JWTScopeClaimList string OAuth2JWTScopeClaimString both OAuth2JWTScopeClaimBoth - Hydra
Strategies Scope Enum - Defines how scopes are matched. For more details have a look at https://github.com/ory/fosite#scopes This governs the "strategies.scope" setting. exact Oauth2ScopeStrategyExact wildcard Oauth2ScopeStrategyWildcard
- Kratos
Selfservice Flows Recovery UseEnum - Configures the Ory Kratos Recovery strategy to use ("link" or "code") This governs the "selfservice.flows.recovery.use" setting. link SelfServiceMessageVerificationStrategyLink code SelfServiceMessageVerificationStrategyCode
- Kratos
Selfservice Flows Verification UseEnum - Configures the Ory Kratos Strategy to use for Verification This governs the "selfservice.flows.verification.use" setting. link SelfServiceMessageVerificationStrategyLink code SelfServiceMessageVerificationStrategyCode