pub struct CredentialSupportedDraft00 {
pub cryptographic_binding_methods_supported: Option<Vec<String>>,
pub cryptographic_suites_supported: Option<Vec<String>>,
pub format: Option<String>,
pub types: Option<Vec<String>>,
}Expand description
CredentialSupportedDraft00 : Includes information about the supported verifiable credentials.
Fields
cryptographic_binding_methods_supported: Option<Vec<String>>OpenID Connect Verifiable Credentials Cryptographic Binding Methods Supported Contains a list of cryptographic binding methods supported for signing the proof.
cryptographic_suites_supported: Option<Vec<String>>OpenID Connect Verifiable Credentials Cryptographic Suites Supported Contains a list of cryptographic suites methods supported for signing the proof.
format: Option<String>OpenID Connect Verifiable Credentials Format Contains the format that is supported by this authorization server.
types: Option<Vec<String>>OpenID Connect Verifiable Credentials Types Contains the types of verifiable credentials supported.
Implementations
Sourceimpl CredentialSupportedDraft00
impl CredentialSupportedDraft00
Sourcepub fn new() -> CredentialSupportedDraft00
pub fn new() -> CredentialSupportedDraft00
Includes information about the supported verifiable credentials.