pub struct IdentityCredentialsLookupSecretCode {
pub code: Option<String>,
pub used_at: Option<String>,
}Expand description
IdentityCredentialsLookupSecretCode : Recovery codes can be used once and are invalidated after use.
Fields
code: Option<String>A recovery code
used_at: Option<String>Implementations
Sourceimpl IdentityCredentialsLookupSecretCode
impl IdentityCredentialsLookupSecretCode
Sourcepub fn new() -> IdentityCredentialsLookupSecretCode
pub fn new() -> IdentityCredentialsLookupSecretCode
Recovery codes can be used once and are invalidated after use.