pub struct IdentityCredentialsPassword {
pub hashed_password: Option<String>,
pub use_password_migration_hook: Option<bool>,
}Fields
hashed_password: Option<String>HashedPassword is a hash-representation of the password.
use_password_migration_hook: Option<bool>UsePasswordMigrationHook is set to true if the password should be migrated using the password migration hook. If set, and the HashedPassword is empty, a webhook will be called during login to migrate the password.
Implementations
Sourceimpl IdentityCredentialsPassword
impl IdentityCredentialsPassword
pub fn new() -> IdentityCredentialsPassword