Module managed_identity_schema

Module managed_identity_schema 

Structs

ManagedIdentitySchema
ManagedIdentitySchema : Together the name and identity uuid are a unique index constraint. This prevents a user from having schemas with the same name. This also allows schemas to have the same name across the system.