pub struct MessageDispatch {
    pub created_at: String,
    pub error: Option<Value>,
    pub id: String,
    pub message_id: String,
    pub status: StatusEnum,
    pub updated_at: String,
}
MessageDispatch : MessageDispatch represents an attempt of sending a courier message It contains the status of the attempt (failed or successful) and the error if any occured

Fields

created_at: String

CreatedAt is a helper struct field for gobuffalo.pop.

error: Option<Value>id: String

The ID of this message dispatch

message_id: String

The ID of the message being dispatched

status: StatusEnum

The status of this dispatch Either "failed" or "success" failed CourierMessageDispatchStatusFailed success CourierMessageDispatchStatusSuccess

updated_at: String

UpdatedAt is a helper struct field for gobuffalo.pop.

Implementations

MessageDispatch represents an attempt of sending a courier message It contains the status of the attempt (failed or successful) and the error if any occured