pub struct OAuth2ConsentRequest {Show 14 fields
pub acr: Option<String>,
pub amr: Option<Vec<String>>,
pub challenge: String,
pub client: Option<Box<OAuth2Client>>,
pub consent_request_id: Option<String>,
pub context: Option<Value>,
pub login_challenge: Option<String>,
pub login_session_id: Option<String>,
pub oidc_context: Option<Box<OAuth2ConsentRequestOpenIdConnectContext>>,
pub request_url: Option<String>,
pub requested_access_token_audience: Option<Vec<String>>,
pub requested_scope: Option<Vec<String>>,
pub skip: Option<bool>,
pub subject: Option<String>,
}Fields
acr: Option<String>ACR represents the Authentication AuthorizationContext Class Reference value for this authentication session. You can use it to express that, for example, a user authenticated using two factor authentication.
amr: Option<Vec<String>>challenge: StringChallenge is used to retrieve/accept/deny the consent request.
client: Option<Box<OAuth2Client>>consent_request_id: Option<String>ConsentRequestID is the ID of the consent request.
context: Option<Value>login_challenge: Option<String>LoginChallenge is the login challenge this consent challenge belongs to. It can be used to associate a login and consent request in the login & consent app.
login_session_id: Option<String>LoginSessionID is the login session ID. If the user-agent reuses a login session (via cookie / remember flag) this ID will remain the same. If the user-agent did not have an existing authentication session (e.g. remember is false) this will be a new random value. This value is used as the "sid" parameter in the ID Token and in OIDC Front-/Back- channel logout. It’s value can generally be used to associate consecutive login requests by a certain user.
oidc_context: Option<Box<OAuth2ConsentRequestOpenIdConnectContext>>request_url: Option<String>RequestURL is the original OAuth 2.0 Authorization URL requested by the OAuth 2.0 client. It is the URL which initiates the OAuth 2.0 Authorization Code or OAuth 2.0 Implicit flow. This URL is typically not needed, but might come in handy if you want to deal with additional request parameters.
requested_access_token_audience: Option<Vec<String>>requested_scope: Option<Vec<String>>skip: Option<bool>Skip, if true, implies that the client has requested the same scopes from the same user previously. If true, you must not ask the user to grant the requested scopes. You must however either allow or deny the consent request using the usual API call.
subject: Option<String>Subject is the user ID of the end-user that authenticated. Now, that end user needs to grant or deny the scope requested by the OAuth 2.0 client.
Implementations
Sourceimpl OAuth2ConsentRequest
impl OAuth2ConsentRequest
pub fn new(challenge: String) -> OAuth2ConsentRequest