PlanDetails

Struct PlanDetails 

pub struct PlanDetails {
    pub base_fee_monthly: i64,
    pub base_fee_yearly: i64,
    pub custom: bool,
    pub description: String,
    pub development_features: HashMap<String, GenericUsage>,
    pub features: HashMap<String, GenericUsage>,
    pub latest: Option<bool>,
    pub name: String,
    pub production_features: HashMap<String, GenericUsage>,
    pub staging_features: HashMap<String, GenericUsage>,
    pub version: i64,
}

Fields

base_fee_monthly: i64

BaseFeeMonthly is the monthly base fee for the plan.

base_fee_yearly: i64

BaseFeeYearly is the yearly base fee for the plan.

custom: bool

Custom is true if the plan is custom. This means it will be hidden from the pricing page.

description: String

Description is the description of the plan.

development_features: HashMap<String, GenericUsage>features: HashMap<String, GenericUsage>latest: Option<bool>

Latest is true if the plan is the latest version of a plan and should be available for self-service usage.

name: String

Name is the name of the plan.

production_features: HashMap<String, GenericUsage>staging_features: HashMap<String, GenericUsage>version: i64

Version is the version of the plan. The combination of name@version must be unique.

Implementations

Source

impl PlanDetails

pub fn new( base_fee_monthly: i64, base_fee_yearly: i64, custom: bool, description: String, development_features: HashMap<String, GenericUsage>, features: HashMap<String, GenericUsage>, name: String, production_features: HashMap<String, GenericUsage>, staging_features: HashMap<String, GenericUsage>, version: i64, ) -> PlanDetails