pub struct ProjectBrandingTheme {Show 38 fields
pub accent_default_color: Option<String>,
pub accent_disabled_color: Option<String>,
pub accent_emphasis_color: Option<String>,
pub accent_muted_color: Option<String>,
pub accent_subtle_color: Option<String>,
pub background_canvas_color: Option<String>,
pub background_subtle_color: Option<String>,
pub background_surface_color: Option<String>,
pub border_default_color: Option<String>,
pub created_at: String,
pub error_default_color: Option<String>,
pub error_emphasis_color: Option<String>,
pub error_muted_color: Option<String>,
pub error_subtle_color: Option<String>,
pub favicon_type: Option<String>,
pub favicon_url: Option<String>,
pub foreground_default_color: Option<String>,
pub foreground_disabled_color: Option<String>,
pub foreground_muted_color: Option<String>,
pub foreground_on_accent_color: Option<String>,
pub foreground_on_dark_color: Option<String>,
pub foreground_on_disabled_color: Option<String>,
pub foreground_subtle_color: Option<String>,
pub id: String,
pub input_background_color: Option<String>,
pub input_disabled_color: Option<String>,
pub input_placeholder_color: Option<String>,
pub input_text_color: Option<String>,
pub logo_type: Option<String>,
pub logo_url: Option<String>,
pub name: String,
pub primary_color: Option<String>,
pub project_branding_id: String,
pub secondary_color: Option<String>,
pub success_emphasis_color: Option<String>,
pub text_default_color: Option<String>,
pub text_disabled_color: Option<String>,
pub updated_at: String,
}Fields
accent_default_color: Option<String>AccentDefaultColor is a hex color code used by the Ory Account Experience theme.
accent_disabled_color: Option<String>AccentDisabledColor is a hex color code used by the Ory Account Experience theme.
accent_emphasis_color: Option<String>AccentEmphasisColor is a hex color code used by the Ory Account Experience theme.
accent_muted_color: Option<String>AccentMutedColor is a hex color code used by the Ory Account Experience theme.
accent_subtle_color: Option<String>AccentSubtleColor is a hex color code used by the Ory Account Experience theme.
background_canvas_color: Option<String>BackgroundCanvasColor is a hex color code used by the Ory Account Experience theme.
background_subtle_color: Option<String>BackgroundSubtleColor is a hex color code used by the Ory Account Experience theme.
background_surface_color: Option<String>BackgroundSurfaceColor is a hex color code used by the Ory Account Experience theme.
border_default_color: Option<String>BorderDefaultColor is a hex color code used by the Ory Account Experience theme.
created_at: StringThe Customization Creation Date.
error_default_color: Option<String>ErrorDefaultColor is a hex color code used by the Ory Account Experience theme.
error_emphasis_color: Option<String>ErrorEmphasisColor is a hex color code used by the Ory Account Experience theme.
error_muted_color: Option<String>ErrorMutedColor is a hex color code used by the Ory Account Experience theme.
error_subtle_color: Option<String>ErrorSubtleColor is a hex color code used by the Ory Account Experience theme.
favicon_type: Option<String>Favicon Type The Favicon mime type.
favicon_url: Option<String>Favicon URL Favicon can be an https:// or base64:// URL. If the URL is not allowed, the favicon will be stored inside the Ory Network storage bucket.
foreground_default_color: Option<String>ForegroundDefaultColor is a hex color code used by the Ory Account Experience theme.
foreground_disabled_color: Option<String>ForegroundDisabledColor is a hex color code used by the Ory Account Experience theme.
foreground_muted_color: Option<String>ForegroundMutedColor is a hex color code used by the Ory Account Experience theme.
foreground_on_accent_color: Option<String>ForegroundOnAccentColor is a hex color code used by the Ory Account Experience theme.
foreground_on_dark_color: Option<String>ForegroundOnDarkColor is a hex color code used by the Ory Account Experience theme.
foreground_on_disabled_color: Option<String>ForegroundOnDisabledColor is a hex color code used by the Ory Account Experience theme.
foreground_subtle_color: Option<String>ForegroundSubtleColor is a hex color code used by the Ory Account Experience theme.
id: StringThe customization theme ID.
input_background_color: Option<String>InputBackgroundColor is a hex color code used by the Ory Account Experience theme.
input_disabled_color: Option<String>InputDisabledColor is a hex color code used by the Ory Account Experience theme.
input_placeholder_color: Option<String>InputPlaceholderColor is a hex color code used by the Ory Account Experience theme.
input_text_color: Option<String>InputTextColor is a hex color code used by the Ory Account Experience theme.
logo_type: Option<String>Logo Type The Logo mime type.
logo_url: Option<String>Logo URL Logo can be an https:// or base64:// URL. If the URL is not allowed, the logo will be stored inside the Ory Network storage bucket.
name: StringThe customization theme name.
primary_color: Option<String>Primary color is an hsla color value used to derive the other colors from for the Ory Account Experience theme.
project_branding_id: StringThe ProjectBranding ID this customization is associated with.
secondary_color: Option<String>Secondary color is a hsla color code used to derive the other colors from for the Ory Account Experience theme.
success_emphasis_color: Option<String>SuccessEmphasisColor is a hex color code used by the Ory Account Experience theme.
text_default_color: Option<String>TextDefaultColor is a hex color code used by the Ory Account Experience theme.
text_disabled_color: Option<String>TextDisabledColor is a hex color code used by the Ory Account Experience theme.
updated_at: StringLast Time Branding was Updated.
Implementations