pub enum RecoveryFlowState {
ChooseMethod,
SentEmail,
PassedChallenge,
}Expand description
RecoveryFlowState : The experimental state represents the state of a recovery flow. This field is EXPERIMENTAL and subject to change! The experimental state represents the state of a recovery flow. This field is EXPERIMENTAL and subject to change!
Variants