pub struct RegistrationFlow {
    pub active: Option<IdentityCredentialsType>,
    pub expires_at: String,
    pub id: String,
    pub issued_at: String,
    pub oauth2_login_challenge: Option<String>,
    pub oauth2_login_request: Option<Box<OAuth2LoginRequest>>,
    pub request_url: String,
    pub return_to: Option<String>,
    pub _type: String,
    pub ui: Box<UiContainer>,
}

Fields

active: Option<IdentityCredentialsType>expires_at: String

ExpiresAt is the time (UTC) when the flow expires. If the user still wishes to log in, a new flow has to be initiated.

id: String

ID represents the flow’s unique ID. When performing the registration flow, this represents the id in the registration ui’s query parameter: http://<selfservice.flows.registration.ui_url>/?flow=

issued_at: String

IssuedAt is the time (UTC) when the flow occurred.

oauth2_login_challenge: Option<String>oauth2_login_request: Option<Box<OAuth2LoginRequest>>request_url: String

RequestURL is the initial URL that was requested from Ory Kratos. It can be used to forward information contained in the URL’s path or query for example.

return_to: Option<String>

ReturnTo contains the requested return_to URL.

_type: String

The flow type can either be api or browser.

ui: Box<UiContainer>

Implementations