RejectOAuth2Request

Struct RejectOAuth2Request 

pub struct RejectOAuth2Request {
    pub error: Option<String>,
    pub error_debug: Option<String>,
    pub error_description: Option<String>,
    pub error_hint: Option<String>,
    pub status_code: Option<i64>,
}

Fields

error: Option<String>

The error should follow the OAuth2 error format (e.g. invalid_request, login_required). Defaults to request_denied.

error_debug: Option<String>

Debug contains information to help resolve the problem as a developer. Usually not exposed to the public but only in the server logs.

error_description: Option<String>

Description of the error in a human readable format.

error_hint: Option<String>

Hint to help resolve the error.

status_code: Option<i64>

Represents the HTTP status code of the error (e.g. 401 or 403) Defaults to 400

Implementations