pub struct Relationships {
pub next_page_token: Option<String>,
pub relation_tuples: Option<Vec<Relationship>>,
}Expand description
Relationships : Paginated Relationship List
Fields
next_page_token: Option<String>The opaque token to provide in a subsequent request to get the next page. It is the empty string iff this is the last page.
relation_tuples: Option<Vec<Relationship>>Implementations
Sourceimpl Relationships
impl Relationships
Sourcepub fn new() -> Relationships
pub fn new() -> Relationships
Paginated Relationship List