SelfRevokeApiKeyRequest

Struct SelfRevokeApiKeyRequest 

pub struct SelfRevokeApiKeyRequest {
    pub credential: Option<String>,
    pub reason: Option<RevocationReason>,
}
SelfRevokeApiKeyRequest : SelfRevokeAPIKeyRequest allows an API key holder to revoke their own key by providing the full key secret as proof of possession.

Fields

credential: Option<String>reason: Option<RevocationReason>

Implementations

Source

impl SelfRevokeApiKeyRequest

pub fn new() -> SelfRevokeApiKeyRequest

SelfRevokeAPIKeyRequest allows an API key holder to revoke their own key by providing the full key secret as proof of possession.