pub struct Session {
    pub active: Option<bool>,
    pub authenticated_at: Option<String>,
    pub authentication_methods: Option<Vec<SessionAuthenticationMethod>>,
    pub authenticator_assurance_level: Option<AuthenticatorAssuranceLevel>,
    pub devices: Option<Vec<SessionDevice>>,
    pub expires_at: Option<String>,
    pub id: String,
    pub identity: Box<Identity>,
    pub issued_at: Option<String>,
}
Session : A Session

Fields

active: Option<bool>

Active state. If false the session is no longer active.

authenticated_at: Option<String>

The Session Authentication Timestamp When this session was authenticated at. If multi-factor authentication was used this is the time when the last factor was authenticated (e.g. the TOTP code challenge was completed).

authentication_methods: Option<Vec<SessionAuthenticationMethod>>

A list of authenticators which were used to authenticate the session.

authenticator_assurance_level: Option<AuthenticatorAssuranceLevel>devices: Option<Vec<SessionDevice>>

Devices has history of all endpoints where the session was used

expires_at: Option<String>

The Session Expiry When this session expires at.

id: String

Session ID

identity: Box<Identity>issued_at: Option<String>

The Session Issuance Timestamp When this session was issued at. Usually equal or close to authenticated_at.

Implementations

A Session