pub struct SessionAuthenticationMethod {
pub aal: Option<AuthenticatorAssuranceLevel>,
pub completed_at: Option<String>,
pub method: Option<MethodEnum>,
pub organization: Option<String>,
pub provider: Option<String>,
pub upstream_acr: Option<String>,
pub upstream_amr: Option<Vec<String>>,
}Expand description
SessionAuthenticationMethod : A singular authenticator used during authentication / login.
Fields
aal: Option<AuthenticatorAssuranceLevel>completed_at: Option<String>When the authentication challenge was completed.
method: Option<MethodEnum>The method used in this authenticator. password CredentialsTypePassword oidc CredentialsTypeOIDC totp CredentialsTypeTOTP lookup_secret CredentialsTypeLookup webauthn CredentialsTypeWebAuthn code CredentialsTypeCodeAuth passkey CredentialsTypePasskey profile CredentialsTypeProfile saml CredentialsTypeSAML deviceauthn CredentialsTypeDeviceAuthn link_recovery CredentialsTypeRecoveryLink CredentialsTypeRecoveryLink is a special credential type linked to the link strategy (recovery flow). It is not used within the credentials object itself. code_recovery CredentialsTypeRecoveryCode
organization: Option<String>The Organization id used for authentication
provider: Option<String>OIDC or SAML provider id used for authentication
upstream_acr: Option<String>UpstreamACR is the acr claim reported by the upstream OIDC provider, if any. Populated only for OIDC login methods when the upstream ID token contained an acr claim.
upstream_amr: Option<Vec<String>>UpstreamAMR is the amr claim reported by the upstream OIDC provider, if any. Populated only for OIDC login methods when the upstream ID token contained an amr claim.
Implementations
Sourceimpl SessionAuthenticationMethod
impl SessionAuthenticationMethod
Sourcepub fn new() -> SessionAuthenticationMethod
pub fn new() -> SessionAuthenticationMethod
A singular authenticator used during authentication / login.