Module subscription
ory_
client
1.22.21
Module subscription
Module Items
Structs
Enums
In ory_
client::
models
ory_client
::
models
Module
subscription
Structs

Subscription
Enums

Currency
Enum
The currency of the subscription. To change this, a new subscription must be created. usd USD eur Euro
Current
Interval
Enum
The currently active interval of the subscription monthly Monthly yearly Yearly