pub struct Subscription {
    pub created_at: String,
    pub current_plan: CurrentPlanEnum,
    pub customer_id: String,
    pub id: String,
    pub ongoing_stripe_checkout_id: Option<String>,
    pub payed_until: String,
    pub plan_changes_at: Option<String>,
    pub plan_changes_to: NullPlan,
    pub status: String,
    pub updated_at: String,
}

Fields

created_at: Stringcurrent_plan: CurrentPlanEnum

The currently active plan of the subscription unknown Unknown free Free start_up_monthly StartUpMonthly start_up_yearly StartUpYearly business_monthly BusinessMonthly business_yearly BusinessYearly custom Custom

customer_id: String

The ID of the stripe customer

id: String

The ID of the subscription

ongoing_stripe_checkout_id: Option<String>payed_until: String

Until when the subscription is payed

plan_changes_at: Option<String>plan_changes_to: NullPlanstatus: String

For collection_method=charge_automatically a subscription moves into incomplete if the initial payment attempt fails. A subscription in this state can only have metadata and default_source updated. Once the first invoice is paid, the subscription moves into an active state. If the first invoice is not paid within 23 hours, the subscription transitions to incomplete_expired. This is a terminal state, the open invoice will be voided and no further invoices will be generated. A subscription that is currently in a trial period is trialing and moves to active when the trial period is over. If subscription collection_method=charge_automatically it becomes past_due when payment to renew it fails and canceled or unpaid (depending on your subscriptions settings) when Stripe has exhausted all payment retry attempts. If subscription collection_method=send_invoice it becomes past_due when its invoice is not paid by the due date, and canceled or unpaid if it is still not paid by an additional deadline after that. Note that when a subscription has a status of unpaid, no subsequent invoices will be attempted (invoices will be created, but then immediately automatically closed). After receiving updated payment information from a customer, you may choose to reopen and pay their closed invoices.

updated_at: String

Implementations