pub struct SuccessfulNativeLogin {
pub continue_with: Option<Vec<ContinueWith>>,
pub session: Box<Session>,
pub session_token: Option<String>,
}Expand description
SuccessfulNativeLogin : The Response for Login Flows via API
Fields
continue_with: Option<Vec<ContinueWith>>Contains a list of actions, that could follow this flow It can, for example, this will contain a reference to the verification flow, created as part of the user’s registration or the token of the session.
session: Box<Session>session_token: Option<String>The Session Token A session token is equivalent to a session cookie, but it can be sent in the HTTP Authorization Header: Authorization: bearer ${session-token} The session token is only issued for API flows, not for Browser flows!
Implementations
Sourceimpl SuccessfulNativeLogin
impl SuccessfulNativeLogin
Sourcepub fn new(session: Session) -> SuccessfulNativeLogin
pub fn new(session: Session) -> SuccessfulNativeLogin
The Response for Login Flows via API