pub struct SuccessfulNativeRegistration {
pub continue_with: Option<Vec<ContinueWith>>,
pub identity: Box<Identity>,
pub session: Option<Box<Session>>,
pub session_token: Option<String>,
}Expand description
SuccessfulNativeRegistration : The Response for Registration Flows via API
Fields
continue_with: Option<Vec<ContinueWith>>Contains a list of actions, that could follow this flow It can, for example, this will contain a reference to the verification flow, created as part of the user’s registration or the token of the session.
identity: Box<Identity>session: Option<Box<Session>>session_token: Option<String>The Session Token This field is only set when the session hook is configured as a post-registration hook. A session token is equivalent to a session cookie, but it can be sent in the HTTP Authorization Header: Authorization: bearer ${session-token} The session token is only issued for API flows, not for Browser flows!
Implementations
Sourceimpl SuccessfulNativeRegistration
impl SuccessfulNativeRegistration
Sourcepub fn new(identity: Identity) -> SuccessfulNativeRegistration
pub fn new(identity: Identity) -> SuccessfulNativeRegistration
The Response for Registration Flows via API