pub struct UiNodeAnchorAttributes {
pub href: String,
pub id: String,
pub node_type: NodeTypeEnum,
pub title: Box<UiText>,
}Fields
href: StringThe link’s href (destination) URL. format: uri
id: StringA unique identifier
node_type: NodeTypeEnumNodeType represents this node’s types. It is a mirror of node.type and is primarily used to allow compatibility with OpenAPI 3.0. In this struct it technically always is "a". text Text input Input img Image a Anchor script Script div Division
title: Box<UiText>Implementations
Sourceimpl UiNodeAnchorAttributes
impl UiNodeAnchorAttributes
pub fn new( href: String, id: String, node_type: NodeTypeEnum, title: UiText, ) -> UiNodeAnchorAttributes