pub struct UiNodeInputAttributes {
    pub autocomplete: Option<AutocompleteEnum>,
    pub disabled: bool,
    pub label: Option<Box<UiText>>,
    pub name: String,
    pub node_type: String,
    pub onclick: Option<String>,
    pub pattern: Option<String>,
    pub required: Option<bool>,
    pub _type: TypeEnum,
    pub value: Option<Value>,
}
UiNodeInputAttributes : InputAttributes represents the attributes of an input node

Fields

autocomplete: Option<AutocompleteEnum>

The autocomplete attribute for the input. email InputAttributeAutocompleteEmail tel InputAttributeAutocompleteTel url InputAttributeAutocompleteUrl current-password InputAttributeAutocompleteCurrentPassword new-password InputAttributeAutocompleteNewPassword one-time-code InputAttributeAutocompleteOneTimeCode

disabled: bool

Sets the input’s disabled field to true or false.

label: Option<Box<UiText>>name: String

The input’s element name.

node_type: String

NodeType represents this node’s types. It is a mirror of node.type and is primarily used to allow compatibility with OpenAPI 3.0. In this struct it technically always is "input".

onclick: Option<String>

OnClick may contain javascript which should be executed on click. This is primarily used for WebAuthn.

pattern: Option<String>

The input’s pattern.

required: Option<bool>

Mark this input field as required.

_type: TypeEnum

The input’s element type. text InputAttributeTypeText password InputAttributeTypePassword number InputAttributeTypeNumber checkbox InputAttributeTypeCheckbox hidden InputAttributeTypeHidden email InputAttributeTypeEmail tel InputAttributeTypeTel submit InputAttributeTypeSubmit button InputAttributeTypeButton datetime-local InputAttributeTypeDateTimeLocal date InputAttributeTypeDate url InputAttributeTypeURI

value: Option<Value>

The input’s value.

Implementations

InputAttributes represents the attributes of an input node