pub struct UpdateFedcmFlowBody {
pub csrf_token: String,
pub nonce: Option<String>,
pub token: String,
pub transient_payload: Option<Value>,
}Fields
csrf_token: StringCSRFToken is the anti-CSRF token.
nonce: Option<String>Nonce is the nonce that was used in the navigator.credentials.get call. If specified, it must match the nonce claim in the token.
token: StringToken contains the result of navigator.credentials.get.
transient_payload: Option<Value>Transient data to pass along to any webhooks.
Implementations
Sourceimpl UpdateFedcmFlowBody
impl UpdateFedcmFlowBody
pub fn new(csrf_token: String, token: String) -> UpdateFedcmFlowBody