Module update_recovery_flow_with_code_method

Module update_recovery_flow_with_code_method 

Structs

UpdateRecoveryFlowWithCodeMethod
UpdateRecoveryFlowWithCodeMethod : Update Recovery Flow with Code Method

Enums

MethodEnum
Method is the method that should be used for this recovery flow Allowed values are link and code. link RecoveryStrategyLink code RecoveryStrategyCode