pub struct UpdateSettingsFlowWithLookupMethod {
    pub csrf_token: Option<String>,
    pub lookup_secret_confirm: Option<bool>,
    pub lookup_secret_disable: Option<bool>,
    pub lookup_secret_regenerate: Option<bool>,
    pub lookup_secret_reveal: Option<bool>,
    pub method: String,
}
UpdateSettingsFlowWithLookupMethod : Update Settings Flow with Lookup Method

Fields

csrf_token: Option<String>

CSRFToken is the anti-CSRF token

lookup_secret_confirm: Option<bool>

If set to true will save the regenerated lookup secrets

lookup_secret_disable: Option<bool>

Disables this method if true.

lookup_secret_regenerate: Option<bool>

If set to true will regenerate the lookup secrets

lookup_secret_reveal: Option<bool>

If set to true will reveal the lookup secrets

method: String

Method Should be set to "lookup" when trying to add, update, or remove a lookup pairing.

Implementations

Update Settings Flow with Lookup Method