pub struct UpdateSettingsFlowWithTotpMethod {
pub csrf_token: Option<String>,
pub method: String,
pub totp_code: Option<String>,
pub totp_unlink: Option<bool>,
pub transient_payload: Option<Value>,
}Expand description
UpdateSettingsFlowWithTotpMethod : Update Settings Flow with TOTP Method
Fields
csrf_token: Option<String>CSRFToken is the anti-CSRF token
method: StringMethod Should be set to "totp" when trying to add, update, or remove a totp pairing.
totp_code: Option<String>ValidationTOTP must contain a valid TOTP based on the
totp_unlink: Option<bool>UnlinkTOTP if true will remove the TOTP pairing, effectively removing the credential. This can be used to set up a new TOTP device.
transient_payload: Option<Value>Transient data to pass along to any webhooks
Implementations
Sourceimpl UpdateSettingsFlowWithTotpMethod
impl UpdateSettingsFlowWithTotpMethod
Sourcepub fn new(method: String) -> UpdateSettingsFlowWithTotpMethod
pub fn new(method: String) -> UpdateSettingsFlowWithTotpMethod
Update Settings Flow with TOTP Method