pub struct UpdateWorkspaceBody {
pub access_policy: Option<AccessPolicyEnum>,
pub name: String,
}Fields
access_policy: Option<AccessPolicyEnum>The access policy of the workspace. If the workspace is not linked to an organization, this field is ignored and the access policy is set to "INVITED_MEMBERS", which allows all invited members to access the workspace. CHECK_ORGANIZATION_AND_WORKSPACE_MEMBERSHIP WorkspaceAccessPolicyOrganizationMembershipRequired Only invited members that are part of the organization defined for the workspace can access it CHECK_ACCESS_PERMISSION WorkspaceAccessPolicyMembershipRequired All invited members can access the workspace, regardless of their organization membership This is useful for migration scenarios where workspaces previously did not have an organization assigned If a user is just a member of a project within the workspace, they’ll still have access to the project, but not to the workspace itself (the default for existing workspaces)
name: StringThe name of the workspace.
Implementations
Sourceimpl UpdateWorkspaceBody
impl UpdateWorkspaceBody
pub fn new(name: String) -> UpdateWorkspaceBody