Module verification_flow_state

Module verification_flow_state 

Enums

VerificationFlowState
VerificationFlowState : The experimental state represents the state of a verification flow. This field is EXPERIMENTAL and subject to change! The experimental state represents the state of a verification flow. This field is EXPERIMENTAL and subject to change!