pub struct Workspace {
pub access_policy: Option<AccessPolicyEnum>,
pub created_at: String,
pub id: String,
pub name: String,
pub organization_id: Option<Option<String>>,
pub subscription_id: Option<Option<String>>,
pub subscription_plan: Option<Option<String>>,
pub updated_at: String,
}Fields
access_policy: Option<AccessPolicyEnum>Controls who can access the workspace and its projects This does not control access level, only who can access it at all. CHECK_ORGANIZATION_AND_WORKSPACE_MEMBERSHIP WorkspaceAccessPolicyOrganizationMembershipRequired Only invited members that are part of the organization defined for the workspace can access it CHECK_ACCESS_PERMISSION WorkspaceAccessPolicyMembershipRequired All invited members can access the workspace, regardless of their organization membership This is useful for migration scenarios where workspaces previously did not have an organization assigned If a user is just a member of a project within the workspace, they’ll still have access to the project, but not to the workspace itself (the default for existing workspaces)
created_at: Stringid: Stringname: Stringorganization_id: Option<Option<String>>subscription_id: Option<Option<String>>subscription_plan: Option<Option<String>>updated_at: String