Creates multiple identities. You can also use this endpoint to import credentials, including passwords, social sign-in settings, and multi-factor authentication methods. You can import: Up to 1,000 identities per request Up to 200 identities per request if including plaintext passwords Avoid importing large batches with plaintext passwords. They can cause timeouts as the passwords need to be hashed before they are stored. If at least one identity is imported successfully, the response status is 200 OK. If all imports fail, the response is one of the following 4xx errors: 400 Bad Request: The request payload is invalid or improperly formatted. 409 Conflict: Duplicate identities or conflicting data were detected. If you get a 504 Gateway Timeout: Reduce the batch size Avoid duplicate identities Pre-hash passwords with BCrypt If the issue persists, contact support.
Calling this endpoint irrecoverably and permanently deletes the identity given its ID. This action can not be undone. This endpoint returns 204 when the identity was deleted or 404 if the identity was not found.
Calling this endpoint extends the given session ID. If session.earliest_possible_extend is set it will only extend the session after the specified time has passed. This endpoint returns per default a 204 No Content response on success. Older Ory Network projects may return a 200 OK response with the session in the body. Returning the session as part of the response will be deprecated in the future and should not be relied upon. This endpoint ignores consecutive requests to extend the same session and returns a 404 error in those scenarios. This endpoint also returns 404 errors if the session does not exist. Retrieve the session ID from the /sessions/whoami endpoint / toSession SDK method.
Return an identity by its ID. You can optionally include credentials (e.g. social sign in connections) in the response by using the include_credential query parameter.
Return an identity by its external ID. You can optionally include credentials (e.g. social sign in connections) in the response by using the include_credential query parameter.
This endpoint updates an identity. The full identity payload, except credentials, is expected. For partial updates, use the patchIdentity operation. A credential can be provided via the credentials field in the request body. If provided, the credentials will be imported and added to the existing credentials of the identity.