Enums
- GetVersion
Error - struct for typed errors of method
get_version
Functions
- get_
version - This endpoint returns the version of Ory Kratos. If the service supports TLS Edge Termination, this endpoint does not require the
X-Forwarded-Protoheader to be set. Be aware that if you are running multiple nodes of this service, the version will never refer to the cluster state, only to a single instance.