Enums
- Check
OplSyntax Error - struct for typed errors of method
check_opl_syntax - Create
Relationship Error - struct for typed errors of method
create_relationship - Delete
Relationships Error - struct for typed errors of method
delete_relationships - GetRelationships
Error - struct for typed errors of method
get_relationships - List
Relationship Namespaces Error - struct for typed errors of method
list_relationship_namespaces - Patch
Relationships Error - struct for typed errors of method
patch_relationships
Functions
- check_
opl_ syntax - The OPL file is expected in the body of the request.
- create_
relationship - Use this endpoint to create a relationship.
- delete_
relationships - Use this endpoint to delete relationships
- get_
relationships - Get all relationships that match the query. Only the namespace field is required.
- list_
relationship_ namespaces - Get all namespaces
- patch_
relationships - Use this endpoint to patch one or more relationships.