pub struct RecoveryFlow {
pub active: Option<String>,
pub continue_with: Option<Vec<ContinueWith>>,
pub expires_at: String,
pub id: String,
pub issued_at: String,
pub request_url: String,
pub return_to: Option<String>,
pub state: Option<Value>,
pub transient_payload: Option<Value>,
pub type: String,
pub ui: Box<UiContainer>,
}Expand description
RecoveryFlow : This request is used when an identity wants to recover their account. We recommend reading the Account Recovery Documentation
Fields
active: Option<String>Active, if set, contains the recovery method that is being used. It is initially not set.
continue_with: Option<Vec<ContinueWith>>Contains possible actions that could follow this flow
expires_at: StringExpiresAt is the time (UTC) when the request expires. If the user still wishes to update the setting, a new request has to be initiated.
id: StringID represents the request’s unique ID. When performing the recovery flow, this represents the id in the recovery ui’s query parameter: http://<selfservice.flows.recovery.ui_url>?request=
issued_at: StringIssuedAt is the time (UTC) when the request occurred.
request_url: StringRequestURL is the initial URL that was requested from Ory Kratos. It can be used to forward information contained in the URL’s path or query for example.
return_to: Option<String>ReturnTo contains the requested return_to URL.
state: Option<Value>State represents the state of this request: choose_method: ask the user to choose a method (e.g. recover account via email) sent_email: the email has been sent to the user passed_challenge: the request was successful and the recovery challenge was passed.
transient_payload: Option<Value>TransientPayload is used to pass data from the recovery flow to hooks and email templates
type: StringThe flow type can either be api or browser.
ui: Box<UiContainer>Implementations
Sourceimpl RecoveryFlow
impl RecoveryFlow
Sourcepub fn new(
expires_at: String,
id: String,
issued_at: String,
request_url: String,
state: Option<Value>,
type: String,
ui: UiContainer,
) -> RecoveryFlow
pub fn new( expires_at: String, id: String, issued_at: String, request_url: String, state: Option<Value>, type: String, ui: UiContainer, ) -> RecoveryFlow
This request is used when an identity wants to recover their account. We recommend reading the Account Recovery Documentation