pub struct UpdateIdentityBody {
pub credentials: Option<Box<IdentityWithCredentials>>,
pub external_id: Option<String>,
pub metadata_admin: Option<Option<Value>>,
pub metadata_public: Option<Option<Value>>,
pub schema_id: String,
pub state: StateEnum,
pub traits: Value,
}Expand description
UpdateIdentityBody : Update Identity Body
Fields
credentials: Option<Box<IdentityWithCredentials>>external_id: Option<String>ExternalID is an optional external ID of the identity. This is used to link the identity to an external system. If set, the external ID must be unique across all identities.
metadata_admin: Option<Option<Value>>Store metadata about the user which is only accessible through admin APIs such as GET /admin/identities/<id>.
metadata_public: Option<Option<Value>>Store metadata about the identity which the identity itself can see when calling for example the session endpoint. Do not store sensitive information (e.g. credit score) about the identity in this field.
schema_id: StringSchemaID is the ID of the JSON Schema to be used for validating the identity’s traits. If set will update the Identity’s SchemaID.
state: StateEnumState is the identity’s state. active StateActive inactive StateInactive
traits: ValueTraits represent an identity’s traits. The identity is able to create, modify, and delete traits in a self-service manner. The input will always be validated against the JSON Schema defined in schema_id.
Implementations